package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.SnowFlake;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcBudgetSettle;
import com.ruoyi.oa.service.ICmcBudgetSettleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc预结算Controller
 * 
 * @author cmc
 * @date 2024-03-22
 */
@RestController
@RequestMapping("/oa/budgetSettle")
public class CmcBudgetSettleController extends BaseController
{
    @Autowired
    private ICmcBudgetSettleService cmcBudgetSettleService;

    /**
     * 查询cmc预结算列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcBudgetSettle cmcBudgetSettle)
    {
        startPage();
        List<CmcBudgetSettle> list = cmcBudgetSettleService.selectCmcBudgetSettleList(cmcBudgetSettle);
        return getDataTable(list);
    }

    /**
     * 导出cmc预结算列表
     */
    @Log(title = "cmc预结算", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcBudgetSettle cmcBudgetSettle)
    {
        List<CmcBudgetSettle> list = cmcBudgetSettleService.selectCmcBudgetSettleList(cmcBudgetSettle);
        ExcelUtil<CmcBudgetSettle> util = new ExcelUtil<CmcBudgetSettle>(CmcBudgetSettle.class);
        util.exportExcel(response, list, "cmc预结算数据");
    }

    /**
     * 获取cmc预结算详细信息
     */
    @GetMapping(value = "/{budgetId}")
    public AjaxResult getInfo(@PathVariable("budgetId") String budgetId)
    {
        return success(cmcBudgetSettleService.selectCmcBudgetSettleByBudgetId(budgetId));
    }

    /**
     * 新增cmc预结算
     */
    @Log(title = "cmc预结算", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcBudgetSettle cmcBudgetSettle)
    {
        return toAjax(cmcBudgetSettleService.insertCmcBudgetSettle(cmcBudgetSettle));
    }

    /**
     * 修改cmc预结算
     */
    @Log(title = "cmc预结算", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcBudgetSettle cmcBudgetSettle)
    {
        return toAjax(cmcBudgetSettleService.updateCmcBudgetSettle(cmcBudgetSettle));
    }

    /**
     * 删除cmc预结算
     */
    @Log(title = "cmc预结算", businessType = BusinessType.DELETE)
	@DeleteMapping("/{budgetIds}")
    public AjaxResult remove(@PathVariable String[] budgetIds)
    {
        return success(cmcBudgetSettleService.deleteCmcBudgetSettleByBudgetIds(budgetIds));
    }
}
