package com.ruoyi.web.controller.oa;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.oa.domain.CmcManageDept;
import com.ruoyi.oa.service.ICmcManageDeptService;
import com.ruoyi.oa.service.ICmcPartyAService;
import com.ruoyi.oa.service.ICmcProjectWorkService;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.web.controller.qyweixin.MessageController;
import com.ruoyi.web.controller.system.SysPostController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcProject;
import com.ruoyi.oa.service.ICmcProjectService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc项目Controller
 * 
 * @author cmc
 * @date 2024-01-30
 */
@RestController
@RequestMapping("/oa/project")
public class CmcProjectController extends BaseController
{
    @Autowired
    private ICmcProjectService cmcProjectService;

    @Autowired
    private ICmcPartyAService cmcPartyAService;

    @Autowired
    private ICmcProjectWorkService cmcProjectWorkService;

    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private ISysUserService userService;

    @Autowired
    private ICmcManageDeptService cmcManageDeptService;

    /**
     * 查询cmc项目列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcProject cmcProject)
    {
        startPage();
        List<CmcProject> list = new ArrayList<>();
        if (cmcProject.getUndertakingDept() != null && cmcProject.getUndertakingDept().equals("113"))
            list = cmcProjectService.selectCmcInvestProjectList(cmcProject);
        else
            list = cmcProjectService.selectCmcProjectList(cmcProject);
        for (CmcProject project : list) {
            project.setUndertakingDeptName(deptIdToName(project));
            project.setQualityInspectorName(inspectorIdToName(project));
        }
        return getDataTable(list);
    }

    /**
     * 导出cmc项目列表
     */
    @Log(title = "cmc项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcProject cmcProject)
    {
        List<CmcProject> list = new ArrayList<>();
        if (cmcProject.getUndertakingDept() != null && cmcProject.getUndertakingDept().equals("113"))
            list = cmcProjectService.selectCmcInvestProjectList(cmcProject);
        else
            list = cmcProjectService.selectCmcProjectList(cmcProject);
        for (CmcProject project : list) {
            project.setUndertakingDeptName(deptIdToName(project));
            project.setQualityInspectorName(inspectorIdToName(project));
        }
        ExcelUtil<CmcProject> util = new ExcelUtil<CmcProject>(CmcProject.class);
        util.exportExcel(response, list, "cmc项目数据");
    }

    /**
     * 获取cmc项目详细信息
     */
    @GetMapping(value = "/{projectId}")
    public AjaxResult getInfo(@PathVariable("projectId") String projectId)
    {
        CmcProject cmcProject = cmcProjectService.selectCmcProjectByProjectId(projectId);
        cmcProject.setUndertakingDeptName(deptIdToName(cmcProject));
        String qualityInspector = cmcProject.getQualityInspector();
        StringBuilder qualityInspectorName = new StringBuilder();
        if (qualityInspector != null && !qualityInspector.equals("") && qualityInspector.split(",").length > 0) {
            for (String inspector : qualityInspector.split(","))
                qualityInspectorName.append(userService.selectUserById(Long.parseLong(inspector)).getNickName()).append(",");
            cmcProject.setQualityInspectorName(qualityInspectorName.substring(0, qualityInspectorName.length() - 1));
        }
        return success(cmcProject);
    }

    /**
     * 获取cmc项目详细信息
     */
    @GetMapping("/projectNumber")
    public AjaxResult getProjectNumberByYear(CmcProject cmcProject)
    {
        List<CmcProject> list = cmcProjectService.selectCmcProjectList(cmcProject);
        String number = list.get(0).getProjectNumber().substring(5);
        String projectNumber = cmcProject.getProjectNumber() + (Integer.parseInt(number) + 1);
        return success(projectNumber);
    }

    /**
     * 新增cmc项目
     */
    @Log(title = "cmc项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcProject cmcProject) throws IOException {
        cmcProject.setRegisterTime(new Date());
        cmcProject.setIsFinished("0");
        if (cmcProject.getUndertakingDept().contains(",")) {
            cmcProject.setLeadDept(cmcProject.getUndertakingDept().substring(0,3));
            cmcProject.setJoinDept(cmcProject.getUndertakingDept().substring(4));
        }
        else
            cmcProject.setLeadDept(cmcProject.getUndertakingDept());
        return toAjax(cmcProjectService.insertCmcProject(cmcProject));
    }

    /**
     * 修改cmc项目
     */
    @Log(title = "cmc项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcProject cmcProject)
    {
        return toAjax(cmcProjectService.updateCmcProject(cmcProject));
    }

    /**
     * 登记项目发送企业微信消息
     */
    @PostMapping("/sendMessage")
    public AjaxResult sendMessage(@RequestBody CmcProject cmcProject) throws IOException {
        String message = "经营发展部已发起项目登记：  \n>" +
                "登记人： <font color='info'>" + userService.selectUserById(cmcProject.getProjectRegistrant()).getNickName() + "</font>  \n>" +
                "项目编号：" + cmcProject.getProjectNumber() + "  \n>" +
                "项目名称：" + cmcProject.getProjectName() + "  \n>" +
                "  \n>" +
                "项目类型：<font color='comment'>" + cmcProject.getProjectType() + "</font>  \n>" +
                "项目来源：" + (cmcProject.getProjectSource().equals("0") ? "院内" : "院外") +"  \n>" +
                "甲方单位：" + cmcPartyAService.selectCmcPartyAByPartyAId(cmcProject.getPartyAId()).getPartyAName() + "  \n>" +
                "  \n>" +
                "承担部门：<font color='warning'>" + deptIdToName(cmcProject) + "</font>  \n>" +
                "请您确认承担部门，及时跟进项目流转  \n>" +
                "  \n>";
        if (cmcProject.getUndertakingDept() != null) {
            String deptString = cmcProject.getUndertakingDept() + ",105";
            List<String> managerList = new ArrayList<>();
            managerList.add("WangRongHua");
            managerList.add("YuSiHan");
            String[] deptId = deptString.split(",");
            for (String dept : deptId) {
                    List<SysUser> manageList = getManageId(dept, "");
                    for (SysUser manager : manageList) {
                        managerList.add(manager.getPinyin());

                }
            }
            MessageController.sendAppMessage(message, StringUtils.join(managerList, "|"));
        }
        return success();
    }

    /**
     * 删除cmc项目
     */
    @Log(title = "cmc项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{projectIds}")
    public AjaxResult remove(@PathVariable String[] projectIds)
    {
        cmcProjectWorkService.deleteCmcProjectWorkByProjectIds(projectIds);
        return success(cmcProjectService.deleteCmcProjectByProjectIds(projectIds));
    }

    public String deptIdToName(CmcProject cmcProject) {
        String underTakingDept = cmcProject.getUndertakingDept();
        StringBuilder underTakingDeptName = new StringBuilder();
        if (underTakingDept != null && !underTakingDept.equals("") && underTakingDept.split(",").length > 0) {
            for (String dept : underTakingDept.split(","))
                underTakingDeptName.append(deptService.selectDeptById(Long.parseLong(dept)).getDeptName()).append(",");
            cmcProject.setUndertakingDeptName(underTakingDeptName.substring(0, underTakingDeptName.length() - 1));
        }
        return cmcProject.getUndertakingDeptName();
    }

    public String inspectorIdToName(CmcProject cmcProject) {
        String qualityInspector = cmcProject.getQualityInspector();
        StringBuilder qualityInspectorName = new StringBuilder();
        if (qualityInspector != null && !qualityInspector.equals("") && qualityInspector.split(",").length > 0) {
            for (String inspector : qualityInspector.split(","))
                qualityInspectorName.append(userService.selectUserById(Long.parseLong(inspector)).getNickName()).append(",");
            cmcProject.setQualityInspectorName(qualityInspectorName.substring(0, qualityInspectorName.length() - 1));
        }
        return cmcProject.getQualityInspectorName();
    }

    public  List<SysUser> getManageId(String deptId, String partyAId) {
        List<SysUser> userList = new ArrayList<>();
        CmcManageDept cmcManageDept = new CmcManageDept();
        cmcManageDept.setDeptId(deptId);
        cmcManageDept.setPartyAId(partyAId);
        for (CmcManageDept manageDept : cmcManageDeptService.selectCmcManageDeptList(cmcManageDept)) {
            userList.add(userService.selectUserById(manageDept.getUserId()));
        }
        return userList;
    }
}
