package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcWage;
import com.ruoyi.oa.service.ICmcWageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 员工工资Controller
 * 
 * @author cmc
 * @date 2024-09-19
 */
@RestController
@RequestMapping("/oa/wage")
public class CmcWageController extends BaseController
{
    @Autowired
    private ICmcWageService cmcWageService;

    /**
     * 查询员工工资列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcWage cmcWage)
    {
        startPage();
        List<CmcWage> list = cmcWageService.selectCmcWageList(cmcWage);
        return getDataTable(list);
    }

    /**
     * 导出员工工资列表
     */
    @Log(title = "员工工资", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcWage cmcWage)
    {
        List<CmcWage> list = cmcWageService.selectCmcWageList(cmcWage);
        ExcelUtil<CmcWage> util = new ExcelUtil<CmcWage>(CmcWage.class);
        util.exportExcel(response, list, "员工工资数据");
    }

    /**
     * 获取员工工资详细信息
     */
    @GetMapping(value = "/{wageId}")
    public AjaxResult getInfo(@PathVariable("wageId") Integer wageId)
    {
        return success(cmcWageService.selectCmcWageByWageId(wageId));
    }

    /**
     * 新增员工工资
     */
    @Log(title = "员工工资", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcWage cmcWage)
    {
        return toAjax(cmcWageService.insertCmcWage(cmcWage));
    }

    /**
     * 修改员工工资
     */
    @Log(title = "员工工资", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcWage cmcWage)
    {
        return toAjax(cmcWageService.updateCmcWage(cmcWage));
    }

    /**
     * 删除员工工资
     */
    @Log(title = "员工工资", businessType = BusinessType.DELETE)
	@DeleteMapping("/{wageIds}")
    public AjaxResult remove(@PathVariable Integer[] wageIds)
    {
        return toAjax(cmcWageService.deleteCmcWageByWageIds(wageIds));
    }
}
