package com.ruoyi.system.mapper;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.SysUserPost;

/**
 * 用户与岗位关联表 数据层
 * 
 * @author ruoyi
 */
public interface SysUserPostMapper
{
    /**
     * 通过用户ID删除用户和岗位关联
     * 
     * @param userId 用户ID
     * @return 结果
     */
    public int deleteUserPostByUserId(Long userId);

    /**
     * 通过岗位ID查询岗位使用数量
     * 
     * @param postId 岗位ID
     * @return 结果
     */
    public int countUserPostById(Long postId);

    /**
     * 批量删除用户和岗位关联
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteUserPost(Long[] ids);

    /**
     * 批量新增用户岗位信息
     * 
     * @param userPostList 用户岗位列表
     * @return 结果
     */
    public int batchUserPost(List<SysUserPost> userPostList);

    /**
     * 查询高级管理员集合
     *
     * @param
     * @return 高级管理员列表
     */
    public List<SysUser> selectGmAssistant(SysUser user);

    /**
     * 根据岗位查询用户
     *
     * @param
     * @return 用户列表
     */
    public List<SysUser> selectUserListByPostName(String postName);

    /**
     * 查询子公司执行董事
     *
     * @param
     * @return 查询子公司执行董事
     */
    public SysUser selectSubLeaderByUserId(String userId);

    /**
     * 查询子公司总经理
     *
     * @param
     * @return 查询子公司总经理
     */
    public SysUser selectSubGmByUserId(String userId);

    /**
     * 查询分公司经理
     *
     * @param
     * @return 查询分公司经理
     */
    public SysUser selectBranchLeaderByUserId(String userId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectDeptLeaderByUserId(String userId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public List<SysUser> selectDeptLeadersByUserId(String userId);

    /**
     * 查询部门副主任
     *
     * @param
     * @return 查询部门副主任
     */
    public SysUser selectViceDeptLeaderByUserId(String userId);

    /**
     * 查询子公司执行董事
     *
     * @param
     * @return 查询子公司执行董事
     */
    public SysUser selectSubLeaderByDeptId(String userId);

    /**
     * 查询子公司总经理
     *
     * @param
     * @return 查询子公司总经理
     */
    public SysUser selectSubGmByDeptId(String userId);

    /**
     * 查询分公司经理
     *
     * @param
     * @return 查询分公司经理
     */
    public SysUser selectBranchLeaderByDeptId(String userId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectDeptLeaderByDeptId(String deptId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public List<SysUser> selectDeptLeadersByDeptId(String deptId);

    /**
     * 查询部门副主任
     *
     * @param
     * @return 查询部门副主任
     */
    public SysUser selectViceDeptLeaderByDeptId(String deptId);

    /**
     * 查询部门副主任列表
     *
     * @param
     * @return 查询部门副主任列表
     */
    public List<SysUser> selectViceDeptLeaderListByDeptId(String deptId);
}
